"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.serializeArguments = void 0;
const ref_napi_1 = require("@2060.io/ref-napi");
const askar_shared_1 = require("@openwallet-foundation/askar-shared");
const conversion_1 = require("./conversion");
const serialize = (arg) => {
    switch (typeof arg) {
        case 'undefined':
            return ref_napi_1.NULL;
        case 'boolean':
            return +arg;
        case 'string':
            return arg;
        case 'number':
            return arg;
        case 'function':
            return arg;
        case 'object':
            if (arg instanceof Date) {
                return arg.valueOf();
            }
            if (arg instanceof askar_shared_1.ArcHandle ||
                arg instanceof askar_shared_1.StoreHandle ||
                arg instanceof askar_shared_1.SessionHandle ||
                arg instanceof askar_shared_1.ScanHandle) {
                return arg.handle;
            }
            if (arg instanceof askar_shared_1.Key) {
                return arg.handle.handle;
            }
            if (arg instanceof Buffer) {
                return (0, conversion_1.uint8arrayToByteBufferStruct)(arg);
            }
            if (arg instanceof Uint8Array) {
                return (0, conversion_1.uint8arrayToByteBufferStruct)(Buffer.from(arg));
            }
            if (arg instanceof askar_shared_1.Jwk) {
                return (0, conversion_1.uint8arrayToByteBufferStruct)(Buffer.from(arg.toUint8Array()));
            }
            return JSON.stringify(arg);
        default:
            throw new Error('could not serialize value');
    }
};
const serializeArguments = (args) => {
    const retVal = {};
    for (const [key, value] of Object.entries(args)) {
        retVal[key] = serialize(value);
    }
    return retVal;
};
exports.serializeArguments = serializeArguments;
//# sourceMappingURL=serialize.js.map